-- by modelleicher
-- www.schwabenmodding.de / www.ls-modcompany.de
-- Dashboard Lights animation, originally created for Eicher 2070 Koenigstiger
-- 
-- feel free to use / modify / make this better but please keep the credits and add comments as to which parts you modified/used

tractorAnimations = {};

function tractorAnimations.prerequisitesPresent(specializations)
    return true;
end;

function tractorAnimations:load(savegame)

    
    self.turnSignalLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLights#turnSignalLight"));
    self.fuelLevelLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLights#fuelLevelLight"));
    self.oilPressureLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLights#oilPressureLight"));
    self.batteryLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLights#batteryLight"));
    self.fourWheelLight = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLights#fourWheelLight"));

    self.turnSignalLightHigh = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLightsHigh#turnSignalLight"));
    self.fuelLevelLightHigh = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLightsHigh#fuelLevelLight"));
    self.oilPressureLightHigh = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLightsHigh#oilPressureLight"));
    self.batteryLightHigh = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLightsHigh#batteryLight"));
    self.fourWheelLightHigh = Utils.indexToObject(self.components, getXMLString(self.xmlFile, "vehicle.tractorAnimations.dashLightsHigh#fourWheelLight"));
    
    self.oilPressureLightTime = 4000;
    self.batteryLightTime = 9000;
    self.fourWheelLightTime = 1200;
    self.fuelLevelLightTime = 1000;
    
    setVisibility(self.turnSignalLight, false);
    setVisibility(self.fuelLevelLight, false);
    setVisibility(self.oilPressureLight, false);
    setVisibility(self.batteryLight, false);
    setVisibility(self.fourWheelLight, false);
    
    
    setVisibility(self.turnSignalLightHigh, false);
    setVisibility(self.fuelLevelLightHigh, false);
    setVisibility(self.oilPressureLightHigh, false);
    setVisibility(self.batteryLightHigh, false);
    setVisibility(self.fourWheelLightHigh, false);
    
    
end;

function tractorAnimations:delete()
end;
function tractorAnimations:mouseEvent(posX, posY, isDown, isUp, button)
end;
function tractorAnimations:keyEvent(unicode, sym, modifier, isDown)
end;
function tractorAnimations:update(dt)    
    if self:getIsActive() then
        if self.isEntered then
            

            -- turn signals, possible turnLightStates:
            --Lights.TURNLIGHT_HAZARD = 3; Lights.TURNLIGHT_RIGHT = 2; Lights.TURNLIGHT_LEFT = 1; Lights.TURNLIGHT_OFF = 0;
            if self.turnLightState ~= Lights.TURNLIGHT_OFF then
                setVisibility(self.turnSignalLight, true);
                if self:getUseHighProfile() then
                    setVisibility(self.turnSignalLightHigh, true);
                end;
            else
                setVisibility(self.turnSignalLight, false);
                if self:getUseHighProfile() then
                    setVisibility(self.turnSignalLightHigh, false);
                end;
            end;
            
            if self.isMotorStarted then
                
                -- 4WD Light
                -- check if GBAddon is used
                local useGB4WD = false;
                if self.mrGbMS ~= nil and self.mrGbMS.IsOn then
                    useGB4WD = true;
                    if self:mrGbMGetDiffLockMiddle() then
                        setVisibility(self.fourWheelLight, true);
                        if self:getUseHighProfile() then
                            setVisibility(self.fourWheelLightHigh, true);
                        end;
                    else
                        setVisibility(self.fourWheelLight, false);
                        if self:getUseHighProfile() then
                            setVisibility(self.fourWheelLightHigh, false);
                        end;                    
                    end;
                end;
                
                -- check if DriveControl is used
                if not useGB4WD and self.driveControl ~= nil and self.driveControl.fourWDandDifferentials ~= nil then
                    if self.driveControl.fourWDandDifferentials.fourWheel then
                        setVisibility(self.fourWheelLight, true);
                        if self:getUseHighProfile() then
                            setVisibility(self.fourWheelLightHigh, true);
                        end;
                    else
                        setVisibility(self.fourWheelLight, false);
                        if self:getUseHighProfile() then
                            setVisibility(self.fourWheelLightHigh, false);
                        end;
                    end;
                end;
                
                
                -- fuel level light
                if self.fuelCapacity > 0 then
                    local currentFuelPercentage = self.fuelFillLevel / (self.fuelCapacity+0.1);
                    if currentFuelPercentage < 0.15 then
                        setVisibility(self.fuelLevelLight, true);
                        if self:getUseHighProfile() then
                            setVisibility(self.fuelLevelLightHigh, true);
                        end;
                    else
                        setVisibility(self.fuelLevelLight, false);
                        if self:getUseHighProfile() then
                            setVisibility(self.fuelLevelLightHigh, false);
                        end;
                    end;
                end;
                
                -- fuel level Light startup sequence
                if self.fuelLevelLightTime > 0 then
                    self.fuelLevelLightTime = self.fuelLevelLightTime - dt;
                    setVisibility(self.fuelLevelLight, true);
                    if self:getUseHighProfile() then
                        setVisibility(self.fuelLevelLightHigh, true);
                    end;
                elseif self.fuelLevelLightTime < 0 then
                    setVisibility(self.fuelLevelLight, false);
                    if self:getUseHighProfile() then
                        setVisibility(self.fuelLevelLightHigh, false);
                    end;
                    self.fuelLevelLightTime = 0;
                end;                
                
                -- four wheel light startup sequence
                if self.fourWheelLightTime > 0 then
                    self.fourWheelLightTime = self.fourWheelLightTime - dt;
                    setVisibility(self.fourWheelLight, true);
                    if self:getUseHighProfile() then
                        setVisibility(self.fourWheelLightHigh, true);
                    end;
                elseif self.fourWheelLightTime < 0 then
                    setVisibility(self.fourWheelLight, false);
                    if self:getUseHighProfile() then
                        setVisibility(self.fourWheelLightHigh, false);
                    end;
                    self.fourWheelLightTime = 0;
                end;                
                
                -- oil pressure light startup sequence
                if self.oilPressureLightTime > 0 then
                    self.oilPressureLightTime = self.oilPressureLightTime - dt;
                    setVisibility(self.oilPressureLight, true);
                    if self:getUseHighProfile() then
                        setVisibility(self.oilPressureLightHigh, true);
                    end;
                else
                    setVisibility(self.oilPressureLight, false);
                    if self:getUseHighProfile() then
                        setVisibility(self.oilPressureLightHigh, false);
                    end;
                end;
                
                -- battery light startup sequence
                if self.batteryLightTime > 0 then
                    self.batteryLightTime = self.batteryLightTime - dt;
                    setVisibility(self.batteryLight, true);
                    if self:getUseHighProfile() then
                        setVisibility(self.batteryLightHigh, true);
                    end;
                else
                    setVisibility(self.batteryLight, false);
                    if self:getUseHighProfile() then
                        setVisibility(self.batteryLightHigh, false);
                    end;
                end;                
                
            else
                -- reset oil pressure light and battery light
                self.oilPressureLightTime = 4000;
                self.batteryLightTime = 9000;
                self.fourWheelLightTime = 1200;
                self.fuelLevelLightTime = 1000;
                
                
                -- turn everything off
                setVisibility(self.batteryLight, false);
                if self:getUseHighProfile() then
                    setVisibility(self.batteryLightHigh, false);
                end;
                setVisibility(self.oilPressureLight, false);
                if self:getUseHighProfile() then
                    setVisibility(self.oilPressureLightHigh, false);
                end;    
                setVisibility(self.fuelLevelLight, false);
                if self:getUseHighProfile() then
                    setVisibility(self.fuelLevelLightHigh, false);
                end;                
            end;
        end;
    
    
    end;
end;

function tractorAnimations:draw()
end;
